@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 import enum
-from typing import Iterable, TypeVar
+from typing import Callable, Iterable, TypeVar
 
 __all__ = [
     "flatten",
@@ -18,12 +20,14 @@ def flatten(it: Iterable[Iterable[T]]) -> Iterable[T]:
         yield from item
 
 
-def not_none(v: "T | None", message: str = "expected not-None") -> T:
+def not_none(v: "T | None", message: str | Callable[[], str] = "expected not-None") -> T:
     """
     Raise a :class:`RuntimeError` if *v* is `None`, otherwise return *v*.
     """
 
     if v is None:
+        if callable(message):
+            message = message()
         raise RuntimeError(message)
     return v
 
